#!/usr/bin/bash

(( ${EUID} == 0 )) && { echo >&2 "This script should not be run as root!"; exit 1; }

# -------------------------------------------------------------------------------------------------------------------- #
# Get options.
# -------------------------------------------------------------------------------------------------------------------- #

OPTIND=1

while getopts "i:o:p:h" opt; do
  case ${opt} in
    i)
      d_music_in="${OPTARG}"
      ;;
    o)
      d_music_out="${OPTARG}"
      ;;
    p)
      f_playlist="${OPTARG}"
      ;;
    h|*)
      echo "-i [d_music_in] -o [d_music_out] -p [f_playlist]"
      exit 2
      ;;
    \?)
      echo "Invalid option: -${OPTARG}."
      exit 1
      ;;
    :)
      echo "Option -${OPTARG} requires an argument."
      exit 1
      ;;
  esac
done

shift $(( ${OPTIND} - 1 ))

[[ -z "${d_music_in}" ]] || [[ -z "${d_music_out}" ]] || [[ -z "${f_playlist}" ]] && exit 1

# -------------------------------------------------------------------------------------------------------------------- #
# -----------------------------------------------------< SCRIPT >----------------------------------------------------- #
# -------------------------------------------------------------------------------------------------------------------- #

[[ ! -d "${d_music_out}" ]] && mkdir -p "${d_music_out}"
[[ -d "${d_music_in}" ]] && cd "${d_music_in}"

for i in *.mp3; do
  ffmpeg -i "${i}" -acodec libvorbis "${i%mp3}ogg"
done

for i in *.ogg; do
  mv "${i}" "${d_music_out}"
done

cd "${d_music_out}"; find $( pwd ) -iname "*.ogg" > "playlist.txt"


# -------------------------------------------------------------------------------------------------------------------- #
# Exit.
# -------------------------------------------------------------------------------------------------------------------- #

exit 0
